Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(481)

Unified Diff: components/web_contents_delegate_android/android/java/src/org/chromium/components/web_contents_delegate_android/WebContentsDelegateAndroid.java

Issue 267253007: Use LoadURLWithParams in ChromeWebContentsDelegateAndroid (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebased Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/web_contents_delegate_android/android/java/src/org/chromium/components/web_contents_delegate_android/WebContentsDelegateAndroid.java
diff --git a/components/web_contents_delegate_android/android/java/src/org/chromium/components/web_contents_delegate_android/WebContentsDelegateAndroid.java b/components/web_contents_delegate_android/android/java/src/org/chromium/components/web_contents_delegate_android/WebContentsDelegateAndroid.java
index 5094115ce2068ed99a4d4252d71dcc5ce75db295..99dff6a9e0a521d24770e2981bf18f1688e34b8c 100644
--- a/components/web_contents_delegate_android/android/java/src/org/chromium/components/web_contents_delegate_android/WebContentsDelegateAndroid.java
+++ b/components/web_contents_delegate_android/android/java/src/org/chromium/components/web_contents_delegate_android/WebContentsDelegateAndroid.java
@@ -1,4 +1,4 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -47,12 +47,14 @@ public class WebContentsDelegateAndroid {
}
/**
* @param disposition The new tab disposition as per the constants in
* org.chromium.ui.WindowOpenDisposition (See window_open_disposition_list.h
* for the enumeration definitions).
*/
@CalledByNative
- public void openNewTab(String url, String extraHeaders, byte[] postData, int disposition) {
+ public void openNewTab(String url, String extraHeaders, byte[] postData, int disposition,
+ boolean isRendererInitiated) {
}
@CalledByNative
« no previous file with comments | « chrome/browser/android/tab_android.cc ('k') | components/web_contents_delegate_android/web_contents_delegate_android.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -47,12 +47,14 @@ public class WebContentsDelegateAndroid {
}
/**
- * @param disposition The new tab disposition as per the constants in
- * org.chromium.ui.WindowOpenDisposition (See window_open_disposition_list.h
- * for the enumeration definitions).
+ * @param disposition The new tab disposition as per the constants in
+ * org.chromium.ui.WindowOpenDisposition (See
+ * window_open_disposition_list.h for the enumeration definitions).
+ * @param isRendererInitiated Whether or not the renderer initiated this action.
*/
This is Rietveld 408576698